use log::debug;
use peach_lib::password_utils;

use crate::error::PeachWebError;

/// Password save form request handler. This function is for use by a user who is already logged in to change their password.
pub fn save_password_form(
    current_password: String,
    new_password1: String,
    new_password2: String,
) -> Result<(), PeachWebError> {
    debug!("attempting to change password");

    password_utils::verify_password(&current_password)?;

    // if the previous line did not throw an error, then the old password is correct
    password_utils::validate_new_passwords(&new_password1, &new_password2)?;

    // if the previous line did not throw an error, then the new password is valid
    password_utils::set_new_password(&new_password1)?;

    Ok(())
}
