use std::env;

use lazy_static::lazy_static;
use log::info;

mod auth;
mod context;
mod error;
mod router;
mod routes;
mod templates;

lazy_static! {
    // determine run-mode from env var; default to standalone mode (aka peachpub)
    static ref STANDALONE_MODE: bool = match env::var("PEACH_STANDALONE_MODE") {
        // parse the value to a boolean; default to true for any error
        Ok(val) => val.parse().unwrap_or(true),
        Err(_) => true
    };
}

fn main() {
    env_logger::init();

    rouille::start_server("localhost:8000", move |request| {
        info!("Now listening on localhost:8000");

        // static file server: matches on assets in the `static` directory
        if let Some(request) = request.remove_prefix("/static") {
            return rouille::match_assets(&request, "static");
        }

        // configure the router based on run-mode
        if *STANDALONE_MODE {
            info!("Running in standalone mode");
            router::minimal_router(request)
        } else {
            info!("Running in fully-featured mode");
            router::complete_router(request)
        }
    });
}
