use rouille::{router, Request, Response};

use crate::routes;

/// Define router for standalone mode (PeachPub).
pub fn minimal_router(request: &Request) -> Response {
    router!(request,
        (GET) (/) => {
            routes::home::menu()
        },
        (GET) (/help) => {
            routes::help::menu()
        },
        (GET) (/login) => {
            routes::login::login()
        },
        (POST) (/login) => {
            routes::login::login_post(request)
        },
        (GET) (/scuttlebutt/blocks) => {
            routes::scuttlebutt::blocks()
        },
        (GET) (/scuttlebutt/follows) => {
            routes::scuttlebutt::follows()
        },
        (GET) (/scuttlebutt/followers) => {
            routes::scuttlebutt::followers()
        },
        (GET) (/scuttlebutt/friends) => {
            routes::scuttlebutt::friends()
        },
        (GET) (/scuttlebutt/peers) => {
            routes::scuttlebutt::peers()
        },
        (GET) (/scuttlebutt/private) => {
            routes::scuttlebutt::private()
        },
        (GET) (/scuttlebutt/profile) => {
            routes::scuttlebutt::profile()
        },
        (GET) (/settings) => {
            routes::settings::menu()
        },
        (GET) (/settings/admin) => {
            routes::settings::admin()
        },
        (GET) (/settings/admin/configure) => {
            routes::settings::admin_configure()
        },
        (GET) (/settings/admin/add) => {
            routes::settings::admin_add()
        },
        (POST) (/settings/admin/add) => {
            routes::settings::admin_add_post(request)
        },
        (GET) (/settings/admin/change_password) => {
            routes::settings::admin_change_password()
        },
        (POST) (/settings/admin/change_password) => {
            routes::settings::admin_change_password_post(request)
        },
        (POST) (/settings/admin/delete) => {
            routes::settings::admin_delete_post(request)
        },
        (GET) (/settings/scuttlebutt) => {
            routes::settings::scuttlebutt()
        },
        (GET) (/status) => {
            routes::status::status()
        },
        // return 404 if not match is found
        _ => routes::catchers::not_found()
    )
}

/// Define router for fully-featured mode (PeachCloud).
pub fn complete_router(request: &Request) -> Response {
    router!(request,
        (GET) (/async) => {
            routes::home::async_test()
        },
        (GET) (/) => {
            routes::home::menu()
        },
        (GET) (/help) => {
            routes::help::menu()
        },
        (GET) (/login) => {
            routes::login::login()
        },
        (POST) (/login) => {
            routes::login::login_post(request)
        },
        (GET) (/scuttlebutt/blocks) => {
            routes::scuttlebutt::blocks()
        },
        (GET) (/scuttlebutt/follows) => {
            routes::scuttlebutt::follows()
        },
        (GET) (/scuttlebutt/followers) => {
            routes::scuttlebutt::followers()
        },
        (GET) (/scuttlebutt/friends) => {
            routes::scuttlebutt::friends()
        },
        (GET) (/scuttlebutt/peers) => {
            routes::scuttlebutt::peers()
        },
        (GET) (/scuttlebutt/private) => {
            routes::scuttlebutt::private()
        },
        (GET) (/scuttlebutt/profile) => {
            routes::scuttlebutt::profile()
        },
        (GET) (/settings) => {
            routes::settings::menu()
        },
        (GET) (/settings/admin) => {
            routes::settings::admin()
        },
        (GET) (/settings/admin/configure) => {
            routes::settings::admin_configure()
        },
        (GET) (/settings/admin/add) => {
            routes::settings::admin_add()
        },
        (POST) (/settings/admin/add) => {
            routes::settings::admin_add_post(request)
        },
        (GET) (/settings/admin/change_password) => {
            routes::settings::admin_change_password()
        },
        (POST) (/settings/admin/change_password) => {
            routes::settings::admin_change_password_post(request)
        },
        (POST) (/settings/admin/delete) => {
            routes::settings::admin_delete_post(request)
        },
        (GET) (/settings/network) => {
            routes::settings::network()
        },
        (GET) (/settings/network/wifi) => {
            routes::settings::network_list_aps()
        },
        (POST) (/settings/network/wifi/connect) => {
            routes::settings::network_connect_wifi(request)
        },
        (POST) (/settings/network/wifi/disconnect) => {
            routes::settings::network_disconnect_wifi(request)
        },
        (POST) (/settings/network/wifi/forget) => {
            routes::settings::network_forget_wifi(request)
        },
        (GET) (/settings/network/wifi/ssid/{ssid: String}) => {
            routes::settings::network_detail(ssid)
        },
        (GET) (/settings/network/wifi/add) => {
            routes::settings::network_add_ap(None)
        },
        (GET) (/settings/network/wifi/add/{ssid: String}) => {
            routes::settings::network_add_ap(Some(ssid))
        },
        (POST) (/settings/network/wifi/add) => {
            routes::settings::network_add_ap_post(request)
        },
        (GET) (/settings/network/wifi/modify) => {
            routes::settings::network_modify_ap(None)
        },
        // TODO: see if we can use the ?= syntax for ssid param
        (GET) (/settings/network/wifi/modify/{ssid: String}) => {
            routes::settings::network_modify_ap(Some(ssid))
        },
        (POST) (/settings/network/wifi/modify) => {
            routes::settings::network_modify_ap_post(request)
        },
        (GET) (/settings/network/dns) => {
            routes::settings::network_configure_dns()
        },
        (POST) (/settings/network/dns) => {
            routes::settings::network_configure_dns_post(request)
        },
        (GET) (/settings/scuttlebutt) => {
            routes::settings::scuttlebutt()
        },
        (GET) (/status) => {
            routes::status::status()
        },
        (GET) (/status/network) => {
            routes::status::network()
        },
        // return 404 if not match is found
        _ => routes::catchers::not_found()
    )
}
